summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlinkedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlinkedit.h')
-rw-r--r--kpovmodeler/pmlinkedit.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kpovmodeler/pmlinkedit.h b/kpovmodeler/pmlinkedit.h
index 4462393c..935d8940 100644
--- a/kpovmodeler/pmlinkedit.h
+++ b/kpovmodeler/pmlinkedit.h
@@ -31,26 +31,27 @@ class TQPushButton;
/**
* Edit widget for links with a TQLineEdit, a select and a clear button.
*/
-class PMLinkEdit : public QWidget
+class PMLinkEdit : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Creates a link edit widget with parent and name.
*
* Allows the selection of declares of type declareType.
*/
- PMLinkEdit( const TQString& declareType, TQWidget* parent, const char* name = 0 );
+ PMLinkEdit( const TQString& declareType, TQWidget* tqparent, const char* name = 0 );
/**
* Creates a link edit widget with parent and name.
*
* Allows the selection of declares of type declares.
*/
- PMLinkEdit( const TQStringList& declares, TQWidget* parent, const char* name = 0 );
+ PMLinkEdit( const TQStringList& declares, TQWidget* tqparent, const char* name = 0 );
/**
* Creates a link edit widget with parent and name.
*/
- PMLinkEdit( TQWidget* parent, const char* name = 0 );
+ PMLinkEdit( TQWidget* tqparent, const char* name = 0 );
/**
* Sets the displayed object and displays the link
@@ -31,26 +31,27 @@ class TQPushButton;
public:
/**
- * Creates a link edit widget with parent and name.
+ * Creates a link edit widget with tqparent and name.
*
* Allows the selection of declares of type declareType.
@@ -31,26 +31,27 @@ class TQPushButton;
/**
- * Creates a link edit widget with parent and name.
+ * Creates a link edit widget with tqparent and name.
*
* Allows the selection of declares of type declares.
@@ -31,26 +31,27 @@ class TQPushButton;
/**
- * Creates a link edit widget with parent and name.
+ * Creates a link edit widget with tqparent and name.
*/